;; C2012_Time.Lsp            
;; CADALYST Systems Benchmark 2011 v5.4 (released Jul-2011)
;; (c)Copyright 1996-2011, Art Liddle and CADALYST Magazine

;; NOTE:
;; AutoCAD 2012 update: Disabled Viewport Controls
;;                      Adjusted 3D/2D tests to balance times
;;                      Added Battery Rundown Test (99 Loops)
;;                      Renamed files  

;; 6-01-2010 (C2011, v5.3b): disabled navigation cube; renamed files for ACAD 2011;
;; 8-01-09: Used Autodesk's Gstest.arx files for updated 3D tests.
;; 7-01-08: Revised 3D tests: removed Flat, and Gouraud; added Conceptual and Realistic
;;                            adjusted number of repeats; adjusted base times


;; NOTE:
;; 2D test supports R2000 and newer; works with any driver.
;; 3D test requires AutoCAD 2009 (Update #3) or newer.


;;VTENABLE = 0     turns off smooth transitions for pans and zooms
;;cleanscreenon    closes ALL menus
;;cleanscreenoff   returns ALL menus


(setq TST_VER "5.4")
(setq TST_DATE "Jul-2011")

(defun SETVARS_TEST  ()
  ;;set number of 2d arrays
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (setq 2DXARRAY_NUM 4) ;;was 4
  (setq 2DYARRAY_NUM 3) ;;was 3
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (setq DWG1 "c2012_5")
  (setq DWG2 "c2012_1")
  (setq DWG3 "c2012_6")
  (setq DWG4 "c2012_2")
  (setq DWG5 "c2012_7")
  (setq DWG6 "c2012_3")
  (setq DWG7 "c2012_8")
  (setq DWG8 "c2012_4")

  (setq 3DTMP_FILE "c2012_3d.tmp")
  (setq 3DCUR_FILE "c2012_current.dta");;added for new compare feature

  (setq CNFG_FILE "C2012_cnfg.dta")

  (setq TRNSFR_FILE "c2012_next")
  (setq TRNSFR_FILE_EXT "c2012_next.scr")
  (setq TIME_FILE "c2012_time")
  (setq INDX_SCR_FILE "c2012_indx")
  (setq NUM_2D 4);;;;<<---- number of 2d test dwgs
  (setq NUM_3D 4);;;;<<---- number of 3d test dwgs
  (setq TIME_LAST TIME_START)
  (setq DWG (getvar "DWGNAME"))
  (setq TIME_LIST (list))
  (setq LOOPS_LEFT (fix (/ (1- LOOP_DWGS_CNT) (+ NUM_2D NUM_3D))))
  (setq LP_MSG (strcat "\n\n[ "  (rtos LOOPS_LEFT 2 0) " loops left ] --->>  "))) ; end setvars_test

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Create a list of lists (pairs) from a file
;; Single data per line in file
(defun LIST_IN  (A_FILE / A_LIST ITEM1 ITEM2)
  (setq A_LIST (list))
  (while (setq ITEM1 (read-line A_FILE))
    (setq ITEM2 (read-line A_FILE))
    (setq A_LIST (append A_LIST (list (list ITEM1 ITEM2)))) ;_ end of setq
    )                                   ; end while
  )                                     ; end defun list_in


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Error handler
(defun *ERROR*  (MSG)
  (if (/= MSG "function cancelled")
    (if (= MSG "quit / exit abort")
      (princ)
      (princ (strcat "\nError-->  " MSG "\n"))) ; end second if
    (princ))                            ; end first if
  (princ))                              ; end defun *error*
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun TIME_NOTE  (NOTE / TIME_NOW TIME_ELPSD)
  (setq TIME_NOW (* (getvar "DATE") 86400.0))
  (setq TIME_ELPSD (rtos (- TIME_NOW TIME_LAST) 2 4))
  (setq TIME_LAST TIME_NOW)
  (setq X (list NOTE TIME_ELPSD))
  (setq TIME_LIST (append TIME_LIST (list X)))) ;end time_note
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun WAIT_RESET  ()
  (princ (strcat LP_MSG "Pausing for a moment..."))

  (setq AJL (* (getvar "viewsize") 0.003))

  (setq TIME_NOW (* (getvar "DATE") 86400.0))
  (setq TIME_LAST TIME_NOW))            ;end wait_reset
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Write a list of lists (pairs) to a file
;; Single data per line in file
(defun LIST_OUT  (A_LIST A_FILE / CNTR ITEM)
  (setq CNTR 0)
  (setq ITEM (nth CNTR A_LIST))
  (while ITEM
    (write-line (car ITEM) A_FILE)
    (write-line (cadr ITEM) A_FILE)
    (setq CNTR (1+ CNTR))
    (setq ITEM (nth CNTR A_LIST)))      ; end while
  )                                     ; end defun list_out
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; create a sub-list from a list
(defun GET_SUB_LIST  (NUM_OF_ITEMS FIRST_ITEM A_LIST / ITEM ITEM_TO_READ SUB_LIST)
  (setq ITEM_TO_READ (1- FIRST_ITEM))
  (setq SUB_LIST (list))
  (repeat NUM_OF_ITEMS
    (setq SUB_LIST
           (append SUB_LIST
                   (list (setq ITEM (nth ITEM_TO_READ A_LIST)))))
    (setq ITEM_TO_READ (1+ ITEM_TO_READ))) ; end repeat
  (setq SUB_LIST SUB_LIST))             ; end defun get_sub_list
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun TRNSFR  ()
  (setq NOW (rtos (* (getvar "DATE") 86400.0) 2 4))
  (setq FNAME "tot_time.tmp")
  (setq FILE (open FNAME "a"))
  (write-line "Stop time:" FILE)
  (write-line NOW FILE)
  (close FILE)
  (command "_script" INDX_SCR_FILE))     ;end trnsfr;internationalized
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  Start Test Function
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun START_TEST  ()
  (princ (strcat LP_MSG "Starting the test..."))

;;Check for version of AutoCAD, if 2009 or later--turn off Navigation Cube
(setq AVER (substr (getvar "acadver") 1 5))
(setq AVER_REAL (atof (getvar "acadver")))
(if (> AVER_REAL 17.1) 
    (command "_navvcube" "_off");;turn off Navigation Cube;internationalized
    (princ)
);;end if

;;Check for version of AutoCAD, if 2011 or later--turn off Navigation Bar Display
(setq AVER (substr (getvar "acadver") 1 5))
(setq AVER_REAL (atof (getvar "acadver")))
(if (> AVER_REAL 18.0) 
  (command "_navbardisplay" "0");;turn off navigation bar display;internationalized
  (princ)
);;end if


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;Check for version of AutoCAD, if 2009 or later--turn off UCs icon -->  added during C2012 update
(setq AVER (substr (getvar "acadver") 1 5))
(setq AVER_REAL (atof (getvar "acadver")))
(if (> AVER_REAL 17.1) 
    (command "_ucsicon" "_off");;turn off UCS icon;internationalized
   (princ)
);;end if

;;Check for version of AutoCAD, if 2012 or later--turn off viewport control
(setq AVER (substr (getvar "acadver") 1 5))
(setq AVER_REAL (atof (getvar "acadver")))
(if (> AVER_REAL 18.1) 
  (command "_vpcontrol" "_off");;turn off navigation bar display;internationalized
  (princ)
);;end if
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


 (setvar "CMDECHO" 0)
  (command "_undo" "_control" "_none");internationalized
  (setq AVER_REAL (atof (getvar "acadver")))
  (setq ISAVE (getvar "isavepercent"))
  (setq XSAVETIME (getvar "savetime"))
  (setq XOSMODE (getvar "osmode"))
  (setvar "isavepercent" 0);;;;forces full save each time
  (setvar "savetime" 0);;not required
  (setvar "osmode" 0)
  (setq xgridmode (getvar "gridmode"))
  (setvar "gridmode" 0)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;Find Test Type for new option
(setq FNAME CNFG_FILE)
(setq FILE (open FNAME "r"))
(setq CNFG_LIST (LIST_IN FILE))
(close FILE)

  
(setq TEST_TYPE (car (cdr (nth 8 CNFG_LIST))))
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
  ;; find current drawing number 
  (setq CUR_DWG (cond ((= (rem LOOP_DWGS_CNT 8) 0) 1);;<<===== Verify: Number of dwgs hard coded here
                      ((= (rem LOOP_DWGS_CNT 8) 7) 2)
                      ((= (rem LOOP_DWGS_CNT 8) 6) 3)
                      ((= (rem LOOP_DWGS_CNT 8) 5) 4)
                      ((= (rem LOOP_DWGS_CNT 8) 4) 5)
                      ((= (rem LOOP_DWGS_CNT 8) 3) 6)
                      ((= (rem LOOP_DWGS_CNT 8) 2) 7)
                      ((= (rem LOOP_DWGS_CNT 8) 1) 8)))
(wait_reset);;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

); end start_test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  Start setup for 3D tests
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun SETUP3D  ()
  (princ (strcat LP_MSG "Getting ready for test..."))

  (command "_view" "_save" "original");internationalized
  (if (= CUR_DWG 1)
    (progn ;;(setq 2d_dwg dwg1)

;;;;;;tight    (setq PT_ARRAY1 (list 0.000 0.625 2.000))
;;;;;;tight    (setq PT_ARRAY2 (list 0.000 2.000 0.625))
           (setq PT_ARRAY1 (list 7.000 0.000 2.000))
           (setq PT_ARRAY2 (list -7.000 2.000 0.000))

;(setq 3d_centroid (list -6.7056 1.7116 0.0143))
(setq odd_name "dwg5");;;  for saving drawings during test
           (setq PT_ROT1 (list 0.000 2.000 0.625))
           (setq PT_ROTX (list 1.000 2.000 0.625))
           (setq PT_ROTY (list 0.000 3.000 0.625))
           (setq PT_ROTZ (list 0.000 2.000 1.625))) ;end progn
    )                                   ; end if

  (if (= CUR_DWG 3)
    (progn ;; (setq 2d_dwg dwg2)
;;;;;;tight     (setq PT_ARRAY1 (list 0.000 -4.8000 -0.2500))
;;;;;;tight     (setq PT_ARRAY2 (list 0.000 -0.2500 -4.8000))
           (setq PT_ARRAY1 (list 16.000 -4.8000 -0.2500))
           (setq PT_ARRAY2 (list -16.000 -0.2500 -4.8000))

;(setq 3d_centroid (list -6.7056 1.7116 0.0143))
(setq odd_name "dwg6")
           (setq PT_ROT1 (list 0.000 0.000 -4.800))
           (setq PT_ROTX (list 1.000 0.000 -4.800))
           (setq PT_ROTY (list 0.000 1.000 -4.800))
           (setq PT_ROTZ (list 0.000 0.000 -3.900))) ;end progn
    )                                   ; end if

  (if (= CUR_DWG 5)
    (progn ;;    (setq 2d_dwg dwg3)
;;;;;;tight     (setq PT_ARRAY1 (list -8.7299 3.1997 5.1749))
;;;;;;tight     (setq PT_ARRAY2 (list 8.7299 5.1749 3.1997))
           (setq PT_ARRAY1 (list -4.2609 3.1997 5.1749))
           (setq PT_ARRAY2 (list 4.2609 5.1749 3.1997))

;(setq 3d_centroid (list -6.7056 1.7116 0.0143))
(setq odd_name "dwg7")
           (setq PT_ROT1 (list -4.500 5.480 3.09))
           (setq PT_ROTX (list -3.500 5.480 3.09))
           (setq PT_ROTY (list -4.500 6.480 3.09))
           (setq PT_ROTZ (list -4.500 5.480 4.09))) ;end progn
    )                                   ; end if

  (if (= CUR_DWG 7)
    (progn ;;    (setq 2d_dwg dwg4)
;;;;;;tight     (setq PT_ARRAY1 (list -0.5596 13.35000 -2.3944))
;;;;;;tight     (setq PT_ARRAY2 (list 0.5596 -2.3944 13.3500))
           (setq PT_ARRAY1 (list -7.0670 -3.1500 -2.3944))
           (setq PT_ARRAY2 (list -2.3944 -3.1500 7.0670))

;(setq 3d_centroid (list -6.7056 1.7116 0.0143))
(setq odd_name "dwg8")
           (setq PT_ROT1 (list -0.558 -2.3866 9.050))
           (setq PT_ROTX (list 0.442 -2.3866 9.050))
           (setq PT_ROTY (list -0.558 -1.3866 9.050))
           (setq PT_ROTZ (list -0.558 -2.3866 10.050))) ;end progn
    ); end if
); end setup3d
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  Create 3D-Array for later tests
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun ARRAY3D_SETUP  ()
  (princ (strcat LP_MSG "Getting ready to do Polar Array..."))
;;  (WAIT_RESET);; start timer for current test
  (princ (strcat LP_MSG "Doing Polar Array..."))

  (command "_view" "_restore" "original");internationalized
  (command "_plan" "_world");internationalized
  (command "_vpoint" "0,1,0");internationalized
  (command "_ucs" "_view");internationalized
  (if (= CUR_DWG 3)
    (command "_explode" "_all");internationalized
  ); end if

  (command "_regen");internationalized

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  set array values for each drawing
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (= cur_dwg 1)
  (progn
    (setq 3DARRAY_NUM1 6)   ;;was 6      
    (setq 3DARRAY_ANG1 360) ;;was 360
    (setq 3DARRAY_NUM2 3)   ;;was 3; was total of 18 (6x3)
    (setq 3DARRAY_ANG2 90)  ;;was 90
  )
)					; end if
(if (= cur_dwg 3)
  (progn
    (setq 3DARRAY_NUM1 3)   ;;was 3
    (setq 3DARRAY_ANG1 360) ;;was 360
    (setq 3DARRAY_NUM2 3)   ;;was 3; was total of 9 (3x3)
    (setq 3DARRAY_ANG2 90)  ;;was 90
  )
)					; end if
(if (= cur_dwg 5)
  (progn
    (setq 3DARRAY_NUM1 3)    ;;was 3
    (setq 3DARRAY_ANG1 360)  ;;was 360
    (setq 3DARRAY_NUM2 3)    ;;was 3; was total of 9 (3x3)
    (setq 3DARRAY_ANG2 90)   ;;was 90
  )
)					; end if
(if (= cur_dwg 7)
  (progn
    (setq 3DARRAY_NUM1 4)   ;;was 3  
    (setq 3DARRAY_ANG1 360) ;;was 360
    (setq 3DARRAY_NUM2 2)   ;;was 2-1; was total of 6 (3x2)--was total of 3 (3x1)
    (setq 3DARRAY_ANG2 90)  ;;was 90
  )
)					; end if

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;first array
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(command "_array" "_all" "" "_polar" PT_ARRAY1 3DARRAY_NUM1 3DARRAY_ANG1 "_yes");internationalized

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;second array
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (command "_ucs" "_world");internationalized
  (command "_plan" "_world");internationalized
  (command "_regen");internationalized

(if (or (= cur_dwg 1)(= cur_dwg 3)(= cur_dwg 5))
  (progn  
    (command "_vpoint" "0,0,1");internationalized
    (command "_ucs" "_view");internationalized
    
(command "_array" "_all" "" "_polar" PT_ARRAY2 3DARRAY_NUM2 3DARRAY_ANG2 "_yes");internationalized

    (command "_regen");internationalized
  );end progn
); end if

(if (= cur_dwg 7)
  (progn  
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    (command "_vpoint" "1,0,0");internationalized
    (command "_ucs" "_view");internationalized
    (command "_array" "_all" "" "_polar" PT_ARRAY2 3DARRAY_NUM2 3DARRAY_ANG2 "_yes");internationalized
    (command "_regen");internationalized
;;;adjust point for rotations of dwg 7 only
(setq PT_ARRAY2 (list 7.0670 -2.3944 -3.1500))
  ); end progn
); end if

  (command "_ucs" "_world");internationalized
  (command "_zoom" "_e");internationalized

;;save time and test description to file
;;(TIME_NOTE "Standard 3D Array    (CPU) :")
);end std3d_test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  First 3D ARX--not part of index calculations
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun FIRST3D_ARX  ()
  (princ (strcat LP_MSG "Setup for 3D OpenGL tests."))
  (setq XYZ_MAX (getvar "extmax"))
  (setq XYZ_MIN (getvar "extmin"))
  (setq X_MAX (car XYZ_MAX))
  (setq Y_MAX (cadr XYZ_MAX))
  (setq Z_MAX (caddr XYZ_MAX))
  (setq X_MIN (car XYZ_MIN))
  (setq Y_MIN (cadr XYZ_MIN))
  (setq Z_MIN (caddr XYZ_MIN))
  (setq XX (- X_MAX X_MIN))
  (setq YY (- Y_MAX Y_MIN))
  (setq ZZ (- Z_MAX Z_MIN))
  (setq X_MID (+ X_MIN (* XX 0.5)))
  (setq Y_MID (+ Y_MIN (* YY 0.5)))
  (setq Z_MID (+ Z_MIN (* ZZ 0.5)))
  (setq CENTER (list X_MID Y_MID Z_MID))
  (command "_plan" "_world");internationalized
  (command "_dview" "" "_po" PT_ARRAY2 "" "_ca" "45" "-120" "");internationalized
;;;;(command "_dview" "" "_po" center "" "_ca" "45" "-120" "");internationalized
  (command "_zoom" "_e");internationalized

  (command "_zoom" "_c" PT_ARRAY2 "1.00x") ;;<<=========== verify

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;R2000 native using GStest.arx routine
           (princ (strcat LP_MSG "Initial render."))
           (setq ARX_LIST (arx))
  		(setq GS_ARX (member "GStest.arx" ARX_LIST)) ;;back to GStest
           (if (= GS_ARX NIL)
	     (arxload "GStest"))                             
   ) ;end defun first3d_arx
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; GsTest.ARX test<------------------------------------enabled again 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;gsbxywireframe
;;;gsbxyhidden
;;;GsbxyConceptual
;;;GsbxyRealistic
;;;Gsbxycurrent<---------------------------------------uses current mode
;;;gsbxy--all four operations          


(defun GSTEST-4_TEST  ()
  ;;**Rotate and zoom
  (princ (strcat LP_MSG "Getting ready to do Rotate/Zoom in Wireframe mode..."))
  (princ (strcat LP_MSG "Doing Rotate/Zoom in Wireframe mode..."))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  Wireframe shades
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(command "_view" "_save" "original_shade");internationalized
(command "_regen");internationalized
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;(command "shademode" "3d")
(command "_zoom" "1.75x");;; added zoom upfront;internationalized
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  adjust reps and zoom factor to equalize times for each drawing
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (= cur_dwg 1) (progn (setq repnum 10) (setq zm "1.09x"))) ;;was 10--1.10
(if (= cur_dwg 3) (progn (setq repnum 10) (setq zm "1.09x"))) ;;was 10--1.10
(if (= cur_dwg 5) (progn (setq repnum 10) (setq zm "1.09x"))) ;;was 10--1.10
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (= cur_dwg 7) (progn (setq repnum 4) (setq zm "1.09x")));;;;;;; ;;;;;;;;was 10--1.09x
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(WAIT_RESET);; start timer for current test              
    (repeat repnum  
      (command "_GSbxywireframe");;;back to gstest;internationalized
      (command "_zoom" zm);internationalized
    );;end repeat
;;save time and test description to file :
  (TIME_NOTE "Rotate Wireframe   (3D) :")
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  Hidden shades<------------------------------------DISABLED; 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(command "_view" "_restore" "original_shade");internationalized
(command "_regen");internationalized
;;(command "_shademode" "_h");internationalized
(command "_zoom" "1.75x");;; added zoom upfront;internationalized
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  adjust reps and zoom factor to equalize times for each drawing
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (= cur_dwg 1) (progn (setq repnum 1) (setq zm "1.5x"))) ;;was 3--1.15
(if (= cur_dwg 3) (progn (setq repnum 1) (setq zm "1.5x"))) ;;was 3--1.15
(if (= cur_dwg 5) (progn (setq repnum 1) (setq zm "1.5x"))) ;;was 3--1.15
(if (= cur_dwg 7) (progn (setq repnum 1) (setq zm "1.5x"))) ;;was 3--1.15
;
(WAIT_RESET);; start timer for current test              
    (repeat repnum  
      (command "_Gsbxyhidden");;;back to gstest;internationalized
      (command "_zoom" zm);internationalized
    );;end repeat

;save time and test description to file :
  (TIME_NOTE "Rotate Hidden      (3D) :")
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  Conceptual shades
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(command "_view" "_restore" "original_shade");internationalized
(command "_regen");internationalized
;;(command "_shademode" "_f");internationalized
(command "_zoom" "1.75x");;; added zoom upfront;internationalized
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  adjust reps and zoom factor to equalize times for each drawing
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (= cur_dwg 1) (progn (setq repnum 1) (setq zm "1.5x"))) ;;was 5--1.25
(if (= cur_dwg 3) (progn (setq repnum 1) (setq zm "1.5x"))) ;;was 4--1.25
(if (= cur_dwg 5) (progn (setq repnum 1) (setq zm "1.5x"))) ;;was 5--1.25
(if (= cur_dwg 7) (progn (setq repnum 1) (setq zm "1.5x"))) ;;was 3--1.25

(WAIT_RESET);; start timer for current test              
    (repeat repnum  
      (command "_Gsbxyconceptual");;;back to gstest;internationalized
      (command "_zoom" zm);internationalized
    );;end repeat

;;save time and test description to file :
  (TIME_NOTE "Rotate Conceptual  (3D) :")
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  Realistic shades
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(command "_view" "_restore" "original_shade");internationalized
(command "_regen");internationalized
;;(command "_shademode" "_g");internationalized
(command "_zoom" "1.75x");;; added zoom upfront;internationalized
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  adjust reps and zoom factor to equalize times for each drawing
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (= cur_dwg 1) (progn (setq repnum 5) (setq zm "1.09x"))) ;;was 10--1.09
(if (= cur_dwg 3) (progn (setq repnum 5) (setq zm "1.09x"))) ;;was 10--1.09 
(if (= cur_dwg 5) (progn (setq repnum 5) (setq zm "1.09x"))) ;;was 10--1.09  
(if (= cur_dwg 7) (progn (setq repnum 4) (setq zm "1.09x"))) ;;was 10--1.09 

(WAIT_RESET);; start timer for current test
    (repeat repnum  
      (command "_Gsbxyrealistic");;;back to gstest;internationalized
      (command "_zoom" zm);internationalized
    );;end repeat

;;save time and test description to file :
  (TIME_NOTE "Rotate Realistic   (3D) :")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
); end gstest-4
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;  Begin 2D functions: Array Save Test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun ARRAY_TEST  ()
  (princ (strcat LP_MSG "Getting ready to do array test... "))
;; find points for operations
  (setq PLWD (* (getvar "viewsize") 0.003))
  (setq XYZ_MAX (getvar "extmax"))
  (setq XYZ_MIN (getvar "extmin"))
  (setq X_MAX (car XYZ_MAX))
  (setq Y_MAX (cadr XYZ_MAX))
  (setq Z_MAX (caddr XYZ_MAX))
  (setq X_MIN (car XYZ_MIN))
  (setq Y_MIN (cadr XYZ_MIN))
  (setq Z_MIN (caddr XYZ_MIN))
  (setq XX (- X_MAX X_MIN))
  (setq YY (- Y_MAX Y_MIN))
  (setq ZZ (- Z_MAX Z_MIN))
  (setq X_MID (+ X_MIN (* XX 0.5)))
  (setq Y_MID (+ Y_MIN (* YY 0.5)))
  (setq Z_MID (+ Z_MIN (* ZZ 0.5)))
  (setq CENTER (list X_MID Y_MID Z_MID))

  (princ (strcat LP_MSG "Doing array test..."))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 (setenv "MaxArray" "250000")  ;; <<-------- set for large arrays
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(command "_zoom" "_extents");internationalized
(command "_view" "_save" "original_2D");internationalized
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  (if (= CUR_DWG 2)
    (command "_array" "_all" "" "_r" 2DYARRAY_NUM 2DXARRAY_NUM 9096 6360)); end if;internationalized

  (if (= CUR_DWG 4)
    (command "_array" "_all" "" "_r" 2DxARRAY_NUM 2DyARRAY_NUM 1000 1400)); switched x and y for better fit array;internationalized

  (if (= CUR_DWG 6)
    (command "_array" "_all" "" "_r" 2DxARRAY_NUM 2DyARRAY_NUM 1200 3500)); switched x and y for better fit array;internationalized

  (if (= CUR_DWG 8)
    (progn (command "_xref" "_bind" "*");internationalized
           (command "_explode" "_all" "_explode" "_all");internationalized
           (command "_array" "_all" "" "_r" 2DYARRAY_NUM 2DXARRAY_NUM 2875 4050);internationalized
    );; end progn
  ); end if

(command "_zoom" "_e" "_regen");internationalized
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (= cur_dwg 2) (setq repnum 22))  ;;was 22
(if (= cur_dwg 4) (setq repnum 34))  ;;was 34
(if (= cur_dwg 6) (setq repnum 19))  ;;was 19
(if (= cur_dwg 8) (setq repnum 45))  ;;was 45
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(WAIT_RESET);; start timer for current test
(WAIT_RESET);;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(repeat REPNUM (command "_line" "0,0" CENTER ""));internationalized
(repeat REPNUM
    (command "_save" "dustin" "_y");internationalized
    (command "_erase" "_l" "");internationalized
    (princ "\n\n")
); end repeat

(command "_zoom" "_e" "_regen");internationalized

;;save time and test description to file :
  (TIME_NOTE "2D Array/save    (Disk) :")
)  ; end array_test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;  DXFout Test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun DXF_TEST  ()
  (princ (strcat LP_MSG "Getting ready to do DXFout..."))
  (princ (strcat LP_MSG "Doing DXFout..."))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (= cur_dwg 2) (setq repnum 13))    ;;was 12-13
(if (= cur_dwg 4) (setq repnum 18))    ;;was 18
(if (= cur_dwg 6) (setq repnum 8))    ;;was 13-12
(if (= cur_dwg 8) (setq repnum 40))    ;;was 52-40
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(WAIT_RESET)
(WAIT_RESET);;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (= CUR_DWG 8) (command "_xref" "_bind" "*"));end if;internationalized
(repeat REPNUM (command "_dxfout" "connie" "16"));internationalized

;;save time and test description to file :
  (TIME_NOTE "DXFout           (Disk) :"))  ; end dxf_test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;  Save Drawing Test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun SAVE_TEST  ()
  (princ (strcat LP_MSG "Getting ready to Save Drawing..."))
;;;;;;;;;  (WAIT_RESET);; start timer for current test
  (princ (strcat LP_MSG "Saving Drawing..."))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(setq XYZ_MAX (getvar "extmax"))
  (setq XYZ_MIN (getvar "extmin"))
  (setq X_MAX (car XYZ_MAX))
  (setq Y_MAX (cadr XYZ_MAX))
  (setq Z_MAX (caddr XYZ_MAX))
  (setq X_MIN (car XYZ_MIN))
  (setq Y_MIN (cadr XYZ_MIN))
  (setq Z_MIN (caddr XYZ_MIN))
  (setq XX (- X_MAX X_MIN))
  (setq YY (- Y_MAX Y_MIN))
  (setq ZZ (- Z_MAX Z_MIN))
  (setq X_MID (+ X_MIN (* XX 0.5)))
  (setq Y_MID (+ Y_MIN (* YY 0.5)))
  (setq Z_MID (+ Z_MIN (* ZZ 0.5)))
  (setq CENTER (list X_MID Y_MID Z_MID))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (= cur_dwg 2) (setq repnum 18))   ;;was 19
(if (= cur_dwg 4) (setq repnum 31))   ;;was 34-31
(if (= cur_dwg 6) (setq repnum 20))   ;;was 21
(if (= cur_dwg 8) (setq repnum 45))   ;;was 60
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(WAIT_RESET)
(WAIT_RESET);;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (repeat REPNUM (command "_line" "0,0" CENTER ""));internationalized
  (repeat REPNUM
    (command "_save" "dustin" "_y");internationalized
    (command "_erase" "_l" "");internationalized
    (princ "\n\n"))                     ; end repeat
;;save time and test description to file :
  (TIME_NOTE "Save Drawing     (Disk) :")

 ;;(WAIT_RESET)
)  ; end save_test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;  Calculations Test
(defun CALC_TEST  ()
  (setq CNTR 0)
  (princ (strcat LP_MSG "Getting ready to do calculations... "))
  (WAIT_RESET);; start timer for current test
  (princ (strcat LP_MSG "Doing calculations... "))
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (setq CALC_REP 105);;was 115
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  (repeat CALC_REP
    (repeat 11
      (repeat 10
        (repeat 10
          (repeat 10
            (setq PLWD (* (getvar "viewsize") 0.003))
            (setq CNTR (1+ CNTR))
            (setq XYZ_MAX (getvar "extmax"))
            (setq XYZ_MIN (getvar "extmin"))
            (setq X_MAX (car XYZ_MAX))
            (setq Y_MAX (cadr XYZ_MAX))
            (setq Z_MAX (caddr XYZ_MAX))
            (setq X_MIN (car XYZ_MIN))
            (setq Y_MIN (cadr XYZ_MIN))
            (setq Z_MIN (caddr XYZ_MIN))
            (setq XX (- X_MAX X_MIN))
            (setq YY (- Y_MAX Y_MIN))
            (setq ZZ (- Z_MAX Z_MIN))
            (setq X_MID (+ X_MIN (* XX 0.5)))
            (setq Y_MID (+ Y_MIN (* YY 0.5)))
            (setq Z_MID (+ Z_MIN (* ZZ 0.5)))
            (setq CENTER (list X_MID Y_MID Z_MID))
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
            (setq X_qrtr3 (+ X_MIN (* XX 0.75)))
            (setq Y_qrtr3 (+ Y_MIN (* YY 0.66)))
            (setq Z_qrtr3 (+ Z_MIN (* ZZ 1.0)))
            (setq qrtr3  (list X_qrtr3 Y_qrtr3 Z_qrtr3)) ;; lower left edge of last array
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
            (setq CENTERLEFT
                   (list (- X_MID (* PLWD 20)) Y_MID Z_MID)))
                                        ;end repeat 10
          )                             ;end repeat 10
        )                               ;end repeat 10
      )                                 ;end repeat 11
    )                                   ; end repeat 4
  (princ (strcat LP_MSG (rtos CNTR 2 0) " iterations complete, more to do..."))
  (command "_zoom" "_c" CENTER "1x");internationalized
  (repeat CALC_REP
    (repeat 11
      (repeat 10
        (repeat 10
          (repeat 10
            (setq CNTR (1+ CNTR))
            (setq XYZ_VSMAX (getvar "vsmax"))
            (setq XYZ_VSMIN (getvar "vsmin"))
            (setq X_VSMAX (car XYZ_VSMAX))
            (setq Y_VSMAX (cadr XYZ_VSMAX))
            (setq Z_VSMAX (caddr XYZ_VSMAX))
            (setq X_VSMIN (car XYZ_VSMIN))
            (setq Y_VSMIN (cadr XYZ_VSMIN))
            (setq Z_VSMIN (caddr XYZ_VSMIN))
            (setq XXVS (- X_VSMAX X_VSMIN))
            (setq YYVS (- Y_VSMAX Y_VSMIN))
            (setq ZZVS (- Z_VSMAX Z_VSMIN))
            (if (> XXVS YYVS)
              (setq ENDPT
                     (list X_MID (+ Y_MID (* YYVS 0.10)) 0.0))  ;;;; adjust endpoint here for radial plines
              (setq ENDPT 
                     (list X_MID (+ Y_MID (* XXVS 0.10)) 0.0))) ;;;; adjust endpoint here for radial plines
            (setq PANX (* XX 0.25))
            (setq PANY (* YY 0.25))
            (setq RTUP (list PANX PANY))
            (setq DWN (list 0.0 (- PANY)))
            (setq LFT (list (- PANX) 0.0))
            (setq UP (list 0.0 PANY))
            (setq RT (list PANX 0.0))
            (setq LFTDWN (list (- PANX) (- PANY)))) ;end repeat
          )                             ;end repeat
        )                               ;end repeat
      )                                 ;end repeat
    )                                   ; end repeat 4
  (princ (strcat LP_MSG (rtos CNTR 2 0) " iterations complete; done with that task."))
;;save time and test description to file :
  (TIME_NOTE "Calculations      (CPU) :"))  ; end calc_test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;  Create/change layers/delete/redraw
;;;  Short and Long Orthogonal Lines
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun LINE_TEST  ()
  (princ (strcat LP_MSG "Getting ready to do Orthogonal Lines..."))

  (princ (strcat LP_MSG "Doing Orthogonal Lines..."))
  (command "_layer"      "_set"        "0"          "_new";internationalized
           "xredx,xgreenx,xbluex"    "_c"          "_red";internationalized
           "xredx"      "_c"          "_green"      "xgreenx";internationalized
           "_c"          "_blue"       "xbluex"     "");internationalized
  (setq BLK "ajl")                      ; for lines
  (setq SSLIST (ssadd))                 ; create empty list
  (setq SCRNSZ (getvar "screensize"))
  (setq XY_RATIO (/ (car SCRNSZ) (cadr SCRNSZ)))
  (setq YX_RATIO (/ (cadr SCRNSZ) (car SCRNSZ)))
  (setq Y_SCRN (getvar "viewsize"))
  (setq X_SCRN (* Y_SCRN XY_RATIO))
  (setq X_RIGHT (list (+ X_MID (* X_SCRN 0.5)) Y_MID 0.0))
  (setq DIST1 (* PLWD -1.5))
  (setq DIST2Y (* PLWD 4))
  (setq DIST3Y (* PLWD -4))
  (setq DIST2X (* PLWD 3))
  (setq DIST3X (* PLWD -3))
  (command "_line" CENTERLEFT X_RIGHT "");internationalized
  (ssadd (entlast) SSLIST)
  (repeat 10
    (command "_array" "_L" "" "_r" "2" "1" DIST1);internationalized
    (ssadd (entlast) SSLIST))           ;end repeat 10
  (command "_block" BLK CENTER SSLIST "");internationalized
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (= cur_dwg 2) (setq repnum 2))  ;;was 2
(if (= cur_dwg 4) (setq repnum 3))  ;;was 4
(if (= cur_dwg 6) (setq repnum 1))  ;;was 1
(if (= cur_dwg 8) (setq repnum 2))  ;;was 4-3
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(WAIT_RESET);; start timer for current test
(repeat repnum
  (command "_zoom" "_e" "_zoom" "1.15x" "_regen");;start fresh;internationalized
  
 (setq SSLIST1 (ssadd))                ; create empty list
  (command "_insert" BLK CENTER "" "" "0");internationalized
  (ssadd (entlast) SSLIST1)
  (repeat 29
    (command "_array" "_l" "" "_r" "2" "1" DIST2Y);internationalized
    (ssadd (entlast) SSLIST1))          ; end repeat 
(command "_zoom" "1.25x" "_regen");;;;;;;;;;;;;;;;;;;;;;;;;;new;internationalized

  (command "_insert" BLK CENTER YX_RATIO "" "90");internationalized
  (ssadd (entlast) SSLIST1)
  (repeat 59
    (command "_array" "_l" "" "_r" "1" "2" DIST3X);internationalized
    (ssadd (entlast) SSLIST1))          ; end repeat

  (command "_insert" BLK CENTER "" "" "180");internationalized
  (ssadd (entlast) SSLIST1)
  (repeat 29
    (command "_array" "_l" "" "_r" "2" "1" DIST3Y);internationalized
    (ssadd (entlast) SSLIST1))          ; end repeat
(command "_zoom" "1.25x" "_regen");;;;;;;;;;;;;;;;;;;;;;;;;;new;internationalized

  (command "_insert" BLK CENTER YX_RATIO "" "270");internationalized
  (ssadd (entlast) SSLIST1)
  (repeat 59
    (command "_array" "_l" "" "_r" "1" "2" DIST2X);internationalized
    (ssadd (entlast) SSLIST1))          ; end repeat 

  ;;change layers
  (princ (strcat LP_MSG "Orthogonal lines; change layer"))
  (setq CNTR -1)
  (repeat 60
    (setq ITEM (ssname SSLIST1 (setq CNTR (1+ CNTR))))
    (command "_change" ITEM "" "_P" "_la" "xredx" "");internationalized
    (setq ITEM (ssname SSLIST1 (setq CNTR (1+ CNTR))))
    (command "_change" ITEM "" "_P" "_la" "xgreenx" "");internationalized
    (setq ITEM (ssname SSLIST1 (setq CNTR (1+ CNTR))))
    (command "_change" ITEM "" "_P" "_la" "xbluex" "")) ;end repeat;internationalized

(command "_zoom" "1.25x" "_regen");;;;;;;;;;;;;;;;;;;;;;;;;;new;internationalized
  (princ
    (strcat LP_MSG "Orthogonal lines; create short lines"))
  (setq SSLIST1 (ssadd))                ; create empty list

  (command "_insert" BLK CENTER "0.2" "" "0");internationalized
  (ssadd (entlast) SSLIST1)
  (repeat 29
    (command "_array" "_l" "" "_r" "2" "1" DIST2Y);internationalized
    (ssadd (entlast) SSLIST1))          ; end repeat 

  (command "_insert" BLK CENTER "0.2" "" "90");internationalized
  (ssadd (entlast) SSLIST1)
  (repeat 59
    (command "_array" "_l" "" "_r" "1" "2" DIST3X);internationalized
    (ssadd (entlast) SSLIST1))          ; end repeat
;XXXXXXXXXXX(command "_zoom" "1.25x" "_regen");;;;;;;;;;;;;;;;;;;;;;;;;;new;internationalized
  (command "_insert" BLK CENTER "0.2" "" "180");internationalized
  (ssadd (entlast) SSLIST1)
  (repeat 29
    (command "_array" "_l" "" "_r" "2" "1" DIST3Y);internationalized
    (ssadd (entlast) SSLIST1))          ; end repeat 
;XXXXXXXXXXXX(command "_zoom" "1.25x" "_regen");;;;;;;;;;;;;;;;;;;;;;;;;;new;internationalized
  (command "_insert" BLK CENTER "0.2" "" "270");internationalized
  (ssadd (entlast) SSLIST1)
  (repeat 59
    (command "_array" "_l" "" "_r" "1" "2" DIST2X);internationalized
    (ssadd (entlast) SSLIST1))          ; end repeat 
(command "_zoom" "1.25x" "_regen");;;;;;;;;;;;;;;;;;;;;;;;;;new;internationalized

  ;;change layers
  (princ (strcat LP_MSG "Orthogonal lines; change layer"))
  (setq CNTR -1)
  (repeat 60
    (setq ITEM (ssname SSLIST1 (setq CNTR (1+ CNTR))))
    (command "_change" ITEM "" "_P" "_la" "xredx" "");internationalized
    (setq ITEM (ssname SSLIST1 (setq CNTR (1+ CNTR))))
    (command "_change" ITEM "" "_P" "_la" "xgreenx" "");internationalized
    (setq ITEM (ssname SSLIST1 (setq CNTR (1+ CNTR))))
    (command "_change" ITEM "" "_P" "_la" "xbluex" "")) ;end repeat ;internationalized
(command "_zoom" "0.4096x" "_regen");;;;;;;;;;;;;;;;;;;;;;;;;;new;internationalized

;;Delete/redraw 
  (princ
    (strcat LP_MSG "Orthogonal lines; delete, then redraw screen"))
 (repeat 45
    (repeat 8 (command "_erase" "_L" ""));;was 8;internationalized
    (command "_redraw"))                 ; end repeat ;internationalized

(command "_zoom" "1.50x" "_regen");internationalized
 ): end new repeat

;;save time and test description to file
  (TIME_NOTE "Ortho lines        (2D) :")
;;to verify test actions
;(if (= cur_dwg 2) (setq dwg_name "2_lines"))
;(if (= cur_dwg 4) (setq dwg_name "4_lines"))
;(if (= cur_dwg 6) (setq dwg_name "6_lines"))
;(if (= cur_dwg 8) (setq dwg_name "8_lines"))
;(command "_save" dwg_name "_y");internationalized

) ; end line_test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;  Create, move, delete, redraw non-orthogonal plines
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun PLINE_TEST3D  ()
  (princ (strcat LP_MSG "Getting ready to do Non-orthogonal Plines..."))

  (princ (strcat LP_MSG "Doing Non-orthogonal Plines..."))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (= cur_dwg 2) (setq repnum 1))  ;;was 3
(if (= cur_dwg 4) (setq repnum 2))  ;;was 5
(if (= cur_dwg 6) (setq repnum 1))  ;;was 1
(if (= cur_dwg 8) (setq repnum 2))  ;;was 4
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (WAIT_RESET);; start timer for current test
(repeat repnum
  (command "_zoom" "_e" "_zoom" "1.15x" "_regen");;start fresh;internationalized
  (setq SSLIST1 (ssadd))                ; create empty list
  (command "_pline" CENTER "_w" PLWD "" ENDPT "");internationalized
  (ssadd (entlast) SSLIST1)

(repeat 2      ;;;was 0--added this repeat loop
  (repeat 119  ;;;;;;;;;;;;;;;;;;was 239--119
    (command "_array" "_l" "" "_p" CENTER "2" "1.5" "_y")  ;;;;;;;;;;was 2 and 2.5;internationalized
    (ssadd (entlast) SSLIST1)
  ); end repeat 
    (command "_zoom" "1.5x" "_regen");;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;new;internationalized
); end repeat

;;need one more to erase
 (command "_array" "_l" "" "_p" CENTER "2" "1.5" "_y")  ;;;;;;;;;;was 2 and 2.5;internationalized
 (ssadd (entlast) SSLIST1)

 ;;Move/Delete/redraw
  (princ (strcat LP_MSG "Non-orthogonal plines; move"))
  (setq MVR (list (* PLWD 20) 0.0))
  (setq MVL (list (* PLWD -20) 0.0))
  (setq CNTR -2)
  (repeat 119  ;;;;;was 71--119
    (setq ITEM (ssname SSLIST1 (setq CNTR (+ 2 CNTR))))
    (command "_move" ITEM "" "0,0" MVR);internationalized
    (setq ITEM (ssname SSLIST1 (1+ CNTR)))
    (command "_move" ITEM "" "0,0" MVL)) ;end repeat ;internationalized

    (command "_zoom" "0.4444x" "_regen");;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;new;internationalized

(princ
    (strcat LP_MSG "Non-orthogonal plines; delete, then redraw screen"))
  (repeat 24  ;;;;was 24
    (repeat 10 (command "_erase" "_l" ""));; was 6 ; end repeat;internationalized
    (command "_redraw"))                 ;end repeat;internationalized

(command "_zoom" "1.50x" "_regen");;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;new;internationalized
):end new repeat

;;save time and test description to file :
  (TIME_NOTE "Radial plines      (2D) :")
;;to verify test actions
;(if (= cur_dwg 2) (setq dwg_name "2_P-lines"))
;(if (= cur_dwg 4) (setq dwg_name "4_P-lines"))
;(if (= cur_dwg 6) (setq dwg_name "6_P-lines"))
;(if (= cur_dwg 8) (setq dwg_name "8_P-lines"))
;(command "_save" dwg_name "_y");internationalized
) ; end pline_test3d
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;  Text and blocks
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun TEXT_TEST  ()
  (princ (strcat LP_MSG "Getting ready to do Text and Blocks..."))
 
  (princ (strcat LP_MSG "Doing Text and Blocks..."))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;; try truetype font for text test-- takes too long
  ;;(command "_style" "_new" "techniclite" "0" "" "" "" "");internationalized
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  (setq SSLIST (ssadd))                 ; create empty list
  (setq BLK2 "ajl2")
  (setq DIST1 (* -3 PLWD))
  (setq DIST2 (* 7 PLWD))
  (setq DIST3 (* -7 PLWD))
  (setq HT (* 5 PLWD))
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (command "_text" "_j" "_fit" CENTERLEFT X_RIGHT HT "CADALYST Systems Benchmark 2012") ;; ;internationalized
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  (ssadd (entlast) SSLIST)
  (repeat 7
    (command "_array" "_L" "" "_r" "2" "1" DIST1);internationalized
    (ssadd (entlast) SSLIST))           ;end repeat
  (command "_block" BLK2 CENTER SSLIST "");internationalized

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (= cur_dwg 2) (setq repnum 1))  ;;was 1
(if (= cur_dwg 4) (setq repnum 1))  ;;was 1
(if (= cur_dwg 6) (setq repnum 1))  ;;was 1
(if (= cur_dwg 8) (setq repnum 2))  ;;was 2
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;(WAIT_RESET)                               ;;c2001= no wait-reset

(WAIT_RESET);; start timer for current test
(repeat repnum
  (command "_zoom" "_e" "_zoom" "1.15x" "_regen");;start fresh;internationalized
  (setq SSLIST1 (ssadd))                ; create empty list

  (command "_insert" BLK2 CENTER "" "" "0");internationalized
  (ssadd (entlast) SSLIST1)
  (repeat 19
    (command "_array" "_l" "" "_r" "2" "1" DIST2);internationalized
    (ssadd (entlast) SSLIST1))          ; end repeat
  (command "_insert" BLK2 CENTER "" "" "90");internationalized
  (ssadd (entlast) SSLIST1)
  (repeat 24
    (command "_array" "_l" "" "_r" "1" "2" DIST3);internationalized
    (ssadd (entlast) SSLIST1))          ; end repeat
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;(command "_zoom" "1.25x" "_regen");;;new;internationalized
  (command "_insert" BLK2 CENTER "" "" "180");internationalized
  (ssadd (entlast) SSLIST1)
  (repeat 19
    (command "_array" "_l" "" "_r" "2" "1" DIST3);internationalized
    (ssadd (entlast) SSLIST1))          ; end repeat
  (command "_insert" BLK2 CENTER "" "" "270");internationalized
  (ssadd (entlast) SSLIST1)
  (repeat 24
    (command "_array" "_l" "" "_r" "1" "2" DIST2);internationalized
    (ssadd (entlast) SSLIST1))          ; end repeat 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;(command "_zoom" "1.25x" "_regen");;;new;internationalized
;; (command "_zoom" "_c" CENTER "1.0x");internationalized

;;Explode text blocks
  (princ (strcat LP_MSG "Text; explode text blocks"))
  (setq CNTR -1)
  (repeat 90
    (setq ITEM (ssname SSLIST1 (setq CNTR (1+ CNTR))))
    (command "_explode" ITEM))           ;end repeat;internationalized
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;(command "_zoom" "0.512x" "_regen");;;new;internationalized

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;Delete/redraw 
  (princ (strcat LP_MSG "Text; delete, then redraw screen"))
  (repeat 4                                             ;;;was 45----->2         
    (repeat 100 (command "_erase" "_L" "")) ; end repeat   ;;;was 16---->300;internationalized
    (command "_zoom" "1.2x" "_regen")) ;;;;INSERT ZOOM HERE----->was 1.5x  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;"redraw")) ; end repeat;internationalized
  (princ "")

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;(command "_zoom" "1.50x" "_regen") ;;;was 1.50x;internationalized
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
):end new repeat


;;save time and test description to file :
  (TIME_NOTE "Text and Blocks    (2D) :")
;;to verify test actions
;(if (= cur_dwg 2) (setq dwg_name "2_text"))
;(if (= cur_dwg 4) (setq dwg_name "4_text"))
;(if (= cur_dwg 6) (setq dwg_name "6_text"))
;(if (= cur_dwg 8) (setq dwg_name "8_text"))
;(command "_save" dwg_name "_y");internationalized
)  ; end text_test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;**Erase/zoom
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun ERASE_TEST  ()
  (princ (strcat LP_MSG "Getting ready to do multiple erases..."))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (= cur_dwg 2) (progn (setq rep_e 3500)(setq repnum 2)))  ;;was 2500--4
(if (= cur_dwg 4) (progn (setq rep_e 1800)(setq repnum 4)))  ;;was 1600--8
(if (= cur_dwg 6) (progn (setq rep_e 2500)(setq repnum 2)))  ;;was 2500--3 
(if (= cur_dwg 8) (progn (setq rep_e 400)(setq repnum 10)))  ;;was 500--16
(WAIT_RESET)
(command "_zoom" "_w" qrtr3 xyz_max) ;internationalized
(repeat	repnum
  (progn
    (repeat rep_e (command "_erase" "_l" ""));;end inner repeat;internationalized
    (command "_zoom" "1.05x" "_regen");internationalized
  );; end progn
);; end outer repeat

(command "_zoom" "_w" qrtr3 xyz_max) ;internationalized
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
                                    ;;  "
   (TIME_NOTE "Erase/Zoom         (2D) :")
;;to verify test actions
;(if (= cur_dwg 2) (setq dwg_name "2_erase"))
;(if (= cur_dwg 4) (setq dwg_name "4_erase"))
;(if (= cur_dwg 6) (setq dwg_name "6_erase"))
;(if (= cur_dwg 8) (setq dwg_name "8_erase"))
;(command "_save" dwg_name "_y");internationalized
)  ; end erase_test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  Save test times to temp file
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun SAVE_TIMES  ()
  (princ (strcat LP_MSG "Doing some house cleaning..."))
  (setq 3D_TIME TIME_LIST)
  (setq FNAME 3DTMP_FILE)
  (setq FILE (open FNAME "a"))
  (LIST_OUT 3D_TIME FILE)
  (close FILE)
); end save_times
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  Save test times to second file--for new compare feature
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun SAVE_TIMES2  ()
  (princ (strcat LP_MSG "Doing some house cleaning..."))
  (setq 3D_TIME TIME_LIST)
  (setq FNAME 3DCUR_FILE)
  (setq FILE (open FNAME "a"))
  (LIST_OUT 3D_TIME FILE)
  (close FILE)
); end save_times
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;  Setup for next drawing
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun FINISH_TEST  ()
  (princ (strcat LP_MSG "Getting ready for next test drawing..."))
  (setenv "MaxArray" "100000")

  (setq LOOP_DWGS_CNT (1- LOOP_DWGS_CNT))
  (setq NEXT_DWG (1+ CUR_DWG))
  (if (= NEXT_DWG 9)
    (setq NEXT_DWG 1))
  (setq NEXT_DWG (nth (1- NEXT_DWG) DWG_LIST))
  ;; Write transfer script
  (setq FNAME TRNSFR_FILE_EXT)
  (setq FILE (open FNAME "w"))
  (write-line (strcat "_quit _y _open " NEXT_DWG) FILE)
  (setq NOW (rtos (* (getvar "DATE") 86400.0) 2 4))
  (write-line (strcat "(setq TIME_START " NOW " )") FILE)
  (write-line
    (strcat "(setq DWG_LIST '(\042"       DWG1           "\042 \042"
            DWG2           "\042 \042"    DWG3           "\042 \042"
            DWG4           "\042 \042"    DWG5           "\042 \042"
            DWG6           "\042 \042"    DWG7           "\042 \042"
            DWG8           "\042))")
    FILE)
  (write-line
    (strcat "(setq LOOP_DWGS_CNT " (rtos LOOP_DWGS_CNT 2 0) ")")
    FILE)
  (write-line (strcat "(load  \042" TIME_FILE "\042)") FILE)
  (close FILE)
  (setvar "isavepercent" ISAVE)
  (setvar "savetime" XSAVETIME)
  (setvar "osmode" XOSMODE)
  (setvar "gridmode" xgridmode)
;;  (setvar "acisoutver" acis_ver)
  (if (> LOOP_DWGS_CNT 0)
    (command "_script" TRNSFR_FILE);internationalized
    (TRNSFR))                           ;end if
;;;**Done
  )                                     ; end finish_test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;  BEGIN ACTUAL TEST
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; setup variables
   (SETVARS_TEST)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  Start test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
   (START_TEST)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  run 3d test for 3d drawings
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (or (= CUR_DWG 1) (= CUR_DWG 3) (= CUR_DWG 5) (= CUR_DWG 7))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;new for test type option
(if (= TEST_TYPE "2D")
   (progn ;;begin progn for no 3d test
     (princ)
   ) ; end progn for no 3d test

  (progn (setvar "REGENMODE" 1);;;;;verify results of this setting
         (SETUP3D)
         (ARRAY3D_SETUP); 
         (FIRST3D_ARX)  
         (GSTEST-4_TEST); Timed for Index-3D (4 times)
         (SAVE_TIMES)
         (SAVE_TIMES2);;added for new compare feature
   ) ; end progn for yes 3d test

);; end if for test type

)  ; end if for 3d test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  run 2d test for 2d drawings
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(if (or (= CUR_DWG 2) (= CUR_DWG 4) (= CUR_DWG 6) (= CUR_DWG 8))
 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;new for test type option
(if (= TEST_TYPE "3D")
   (progn ;;begin progn for no 2d test
     (princ)
   ) ; end progn for no 3d test

 (progn (setvar "REGENMODE" 1);;;;;verify results of this setting
         (ARRAY_TEST)   ; Timed for Index-Disk
         (DXF_TEST)     ; Timed for Index-Disk
         (SAVE_TEST)    ; Timed for Index-Disk 
         (CALC_TEST)    ; Timed for Index-CPU
         (LINE_TEST)    ; Timed for Index-2D
;(command "_save" cur_dwg "_y");internationalized
         (PLINE_TEST3D) ; Timed for Index-2D
         (TEXT_TEST)    ; Timed for Index-2D
         (ERASE_TEST)   ; Timed for Index-2D
         (SAVE_TIMES)
         (SAVE_TIMES2);;added for new compare feature
   ) ; end progn for yes 2d test

);; end if for test type

)  ; end if for 2d test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  finsh test
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(FINISH_TEST)     ;;done
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

